==> ejc-procost-impl-3.0.0-20220407.063331-14-sources.jar: com/ejianc/business/procost/bean/ShareDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本分摊费用明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_share_detail")
public class ShareDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="share_id")
    private java.lang.Long shareId; // 主表主键ID
    @TableField(value="source_id")
    private java.lang.Long sourceId; // 来源单据主键ID
    @TableField(value="path")
    private java.lang.String path; // 前端跳转路径
    @TableField(value="name")
    private java.lang.String name; // 费用项
    @TableField(value="bill_type")
    private java.lang.String billType; // 单据类型名称
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="happen_date")
    private java.lang.String happenDate; // 发生日期
    @TableField(value="happen_mny")
    private java.math.BigDecimal happenMny; // 发生成本
    @TableField(value="subject_flag")
    private java.lang.Integer subjectFlag; // 是否关联成本科目 0-否，1-是
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称
    
    
    

    /**
     * 主表主键ID
     */
    public java.lang.Long getShareId() {
        return shareId;
    }

    /**
     * 主表主键ID
     */
    public void setShareId(java.lang.Long shareId) {
        this.shareId = shareId;
    }
    /**
     * 来源单据主键ID
     */
    public java.lang.Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据主键ID
     */
    public void setSourceId(java.lang.Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 前端跳转路径
     */
    public java.lang.String getPath() {
        return path;
    }

    /**
     * 前端跳转路径
     */
    public void setPath(java.lang.String path) {
        this.path = path;
    }
    /**
     * 费用项
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 费用项
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据类型名称
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * 单据类型名称
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发生日期
     */
    public String getHappenDate() {
        return happenDate;
    }

    public void setHappenDate(String happenDate) {
        this.happenDate = happenDate;
    }

    /**
     * 发生成本
     */
    public java.math.BigDecimal getHappenMny() {
        return happenMny;
    }

    /**
     * 发生成本
     */
    public void setHappenMny(java.math.BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    /**
     * 是否关联成本科目  0-否，1-是
     */
    public Integer getSubjectFlag() {
        return subjectFlag;
    }

    public void setSubjectFlag(Integer subjectFlag) {
        this.subjectFlag = subjectFlag;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}

==> ejc-procost-impl-3.0.0-20240109.084349-254-sources.jar: com/ejianc/business/procost/bean/ShareDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本分摊费用明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_share_detail")
public class ShareDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="share_id")
    private java.lang.Long shareId; // 主表主键ID
    @TableField(value="source_id")
    private java.lang.Long sourceId; // 来源单据主键ID
    @TableField(value="path")
    private java.lang.String path; // 前端跳转路径
    @TableField(value="name")
    private java.lang.String name; // 费用项
    @TableField(value="bill_type")
    private java.lang.String billType; // 单据类型名称
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="happen_date")
    private java.lang.String happenDate; // 发生日期
    @TableField(value="happen_mny")
    private java.math.BigDecimal happenMny; // 发生成本
    @TableField(value="subject_flag")
    private java.lang.String subjectFlag; // 是否关联成本科目 0-否，1-是
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private java.lang.String createUserName; // 创建人名称
    
    
    

    /**
     * 主表主键ID
     */
    public java.lang.Long getShareId() {
        return shareId;
    }

    /**
     * 主表主键ID
     */
    public void setShareId(java.lang.Long shareId) {
        this.shareId = shareId;
    }
    /**
     * 来源单据主键ID
     */
    public java.lang.Long getSourceId() {
        return sourceId;
    }

    /**
     * 来源单据主键ID
     */
    public void setSourceId(java.lang.Long sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 前端跳转路径
     */
    public java.lang.String getPath() {
        return path;
    }

    /**
     * 前端跳转路径
     */
    public void setPath(java.lang.String path) {
        this.path = path;
    }
    /**
     * 费用项
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 费用项
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据类型名称
     */
    public java.lang.String getBillType() {
        return billType;
    }

    /**
     * 单据类型名称
     */
    public void setBillType(java.lang.String billType) {
        this.billType = billType;
    }
    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 发生日期
     */
    public String getHappenDate() {
        return happenDate;
    }

    public void setHappenDate(String happenDate) {
        this.happenDate = happenDate;
    }

    /**
     * 发生成本
     */
    public java.math.BigDecimal getHappenMny() {
        return happenMny;
    }

    /**
     * 发生成本
     */
    public void setHappenMny(java.math.BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    /**
     * 是否关联成本科目  0-否，1-是
     */
    public String getSubjectFlag() {
        return subjectFlag;
    }

    public void setSubjectFlag(String subjectFlag) {
        this.subjectFlag = subjectFlag;
    }

    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建人名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建人名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    
}
